// Shenzhen 21EDA Electronics
// Development Board Model: A-C5FB
// www.sz-21eda.com
// www.21eda.net

// Learn key recognition, FPGA detection
// key1 key2 key3 key4 state as a data input, digital tube as a status display
// When the key is pressed, the corresponding I/O is low (0), when no pressed key is high (1)
// KEY1 corresponds to the I/O port pin 31
// KEY2 corresponds to the I/O port pin 28
// KEY3 corresponds to the I/O port pin 40
// KEY4 corresponds to the I/O port pin 32
// video tutorials for all of our 21EDA electronic learning boards

module key_led(clk_50M,key,duan_ma,wei_ma);

input clk_50M;         // system clock 50MHz input from pin 17 input.
input [3:0] key;       // key1 key2 key3 key4 is the value of the input key code
output [3:0] wei_ma;   // digital control bit selection
output [7:0] duan_ma;  // digital tube segment code ABCDEFGH

reg [7:0] duan_ma;
reg [3:0] wei_ma;
reg [3:0] key_temp;    // set a register

always@ (posedge clk_50M)
  begin
    key_temp<=key; // assign the value of the key to the register
    case (key_temp)
      4'b1110:duan_ma<=8'b1111_1001; // segment code // KEY1 press to show 1
      4'b1101:duan_ma<=8'b1010_0100; // segment code // KEY1 press to show 2
      4'b1011:duan_ma<=8'b1011_0000; // segment code // KEY1 press to show 3
      4'b0111:duan_ma<=8'b1001_1001; // segment code // KEY1 press to show 4
    endcase
  end


always@ (posedge clk_50M)
  begin
    case(key_temp)  // bit selected signal
      4'b0111:wei_ma<=4'b0111; // press KEY4 4th digit display
      4'b1011:wei_ma<=4'b1011; // press KEY3 3th digit display
      4'b1101:wei_ma<=4'b1101; // press KEY2 2th digit display
      4'b1110:wei_ma<=4'b1110; // press KEY1 1th digit display
    endcase
  end
endmodule

